@@ -33,16 +33,15 @@
 _WP3ContentParsingState::_WP3ContentParsingState():
 	m_colSpan(1),
 	m_rowSpan(1),
-	m_cellFillColor(NULL)
+	m_textBuffer(),
+	m_cellFillColor(0),
+	m_noteReference(),
+	m_tableList()
 {
-	m_textBuffer.clear();
-	m_noteReference.clear();
 }
 
 _WP3ContentParsingState::~_WP3ContentParsingState()
 {
-	m_textBuffer.clear();
-	m_noteReference.clear();
 	DELETEP(m_cellFillColor);
 }
 
@@ -74,7 +73,7 @@ void WP3ContentListener::insertCharacter(const uint16_t character)
 	}
 }
 
-void WP3ContentListener::insertTab(const uint8_t tabType, float tabPosition)
+void WP3ContentListener::insertTab(const uint8_t /* tabType */, float /* tabPosition */)
 {
         if (!isUndoOn())
 	{
@@ -140,13 +139,14 @@ void WP3ContentListener::defineTable(const uint8_t position, const uint16_t left
 		m_ps->m_tableDefinition.m_leftOffset = _movePositionToFirstColumn( (float)((double)leftOffset / (double)WPX_NUM_WPUS_PER_INCH) ) - m_ps->m_paragraphMarginLeft;
 
 		// remove all the old column information
-		m_ps->m_tableDefinition.columns.clear();
-		m_ps->m_tableDefinition.columnsProperties.clear();
+		m_ps->m_tableDefinition.m_columns.clear();
+		m_ps->m_tableDefinition.m_columnsProperties.clear();
 		m_ps->m_numRowsToSkip.clear();
 	}
 }
 
-void WP3ContentListener::addTableColumnDefinition(const uint32_t width, const uint32_t leftGutter, const uint32_t rightGutter, const uint32_t attributes, const uint8_t alignment)
+void WP3ContentListener::addTableColumnDefinition(const uint32_t width, const uint32_t /* leftGutter */,
+						const uint32_t /* rightGutter */, const uint32_t attributes, const uint8_t alignment)
 {
 	if (!isUndoOn())
 	{
@@ -157,13 +157,13 @@ void WP3ContentListener::addTableColumnDefinition(const uint32_t width, const ui
 		colDef.m_rightGutter = (float)((double)width / (double)WPX_NUM_WPUS_PER_INCH);
 
 		// add the new column definition to our table definition
-		m_ps->m_tableDefinition.columns.push_back(colDef);
+		m_ps->m_tableDefinition.m_columns.push_back(colDef);
 		
 		WPXColumnProperties colProp;
 		colProp.m_attributes = attributes;
 		colProp.m_alignment = alignment;
 		
-		m_ps->m_tableDefinition.columnsProperties.push_back(colProp);
+		m_ps->m_tableDefinition.m_columnsProperties.push_back(colProp);
 		
 		// initialize the variable that tells us how many columns to skip
 		m_ps->m_numRowsToSkip.push_back(0);
@@ -206,7 +206,7 @@ void WP3ContentListener::insertCell()
 		
 		RGBSColor tmpCellBorderColor(0x00, 0x00, 0x00, 0x64);
 		_openTableCell((uint8_t)m_parseState->m_colSpan, (uint8_t)m_parseState->m_rowSpan, 0x00000000,       
-				 m_parseState->m_cellFillColor, NULL, &tmpCellBorderColor, TOP);
+				 m_parseState->m_cellFillColor, 0, &tmpCellBorderColor, TOP);
 		DELETEP(m_parseState->m_cellFillColor);
 
 		m_ps->m_isCellWithoutParagraph = true;
@@ -338,7 +338,7 @@ void WP3ContentListener::attributeChange(const bool isOn, const uint8_t attribut
 	}
 }
 
-void WP3ContentListener::undoChange(const uint8_t undoType, const uint16_t undoLevel)
+void WP3ContentListener::undoChange(const uint8_t undoType, const uint16_t /* undoLevel */)
 {
         if (undoType == 0x00) // begin invalid text
                 setUndoOn(true);
@@ -443,8 +443,8 @@ void WP3ContentListener::setTabs(const bool isRelative, const std::vector<WPXTab
 	}
 }
 
-void WP3ContentListener::columnChange(const WPXTextColumnType columnType, const uint8_t numColumns, const std::vector<float> &columnWidth,
-		const std::vector<bool> &isFixedWidth)
+void WP3ContentListener::columnChange(const WPXTextColumnType /* columnType */, const uint8_t numColumns,
+					const std::vector<float> &columnWidth, const std::vector<bool> &isFixedWidth)
 {
 	if (!isUndoOn())
 	{
@@ -464,7 +464,7 @@ void WP3ContentListener::columnChange(const WPXTextColumnType columnType, const
 		if (numColumns > 1)
 		{
 			int i;
-			for (i=0; i<columnWidth.size(); i++)
+			for (i=0; i<(int)columnWidth.size(); i++)
 			{
 				if (isFixedWidth[i])
 					remainingSpace -= columnWidth[i];
@@ -527,7 +527,7 @@ void WP3ContentListener::setTextColor(const RGBSColor *fontColor)
 	}
 }
 
-void WP3ContentListener::setTextFont(const WPXString fontName)
+void WP3ContentListener::setTextFont(const WPXString &fontName)
 {
 	if (!isUndoOn())
 	{
@@ -567,7 +567,7 @@ void WP3ContentListener::insertNoteReference(const WPXString &noteReference)
 
 void WP3ContentListener::insertNote(const WPXNoteType noteType, WP3SubDocument *subDocument)
 {
-	if (!isUndoOn())
+	if (!isUndoOn() && !m_ps->m_isNote)
 	{
 		_closeSpan();
 		m_ps->m_isNote = true;
@@ -593,7 +593,8 @@ void WP3ContentListener::insertNote(const WPXNoteType noteType, WP3SubDocument *
 	}
 }
 
-void WP3ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList, int nextTableIndice)
+void WP3ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter,
+						WPXTableList /* tableList */, int /* nextTableIndice */)
 {
 	// save our old parsing state on our "stack"
 	WP3ContentParsingState *oldParseState = m_parseState;
@@ -633,7 +634,7 @@ void WP3ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, c
 	setUndoOn(oldIsUndoOn);
 }
 	
-void WP3ContentListener::headerFooterGroup(const uint8_t headerFooterType, const uint8_t occurenceBits, WP3SubDocument *subDocument)
+void WP3ContentListener::headerFooterGroup(const uint8_t /* headerFooterType */, const uint8_t /* occurenceBits */, WP3SubDocument *subDocument)
 {
 	if (subDocument)
 		m_subDocuments.push_back(subDocument);			
