@@ -39,40 +39,40 @@ public:
 	WP3StylesListener(std::list<WPXPageSpan> &pageList, WPXTableList tableList, std::vector<WP3SubDocument *> &subDocuments);
 
 	void startDocument() {}
-	void insertCharacter(const uint16_t character) { if (!isUndoOn()) m_currentPageHasContent = true; }
-	void insertTab(const uint8_t tabType, float tabPosition) { if (!isUndoOn()) m_currentPageHasContent = true; }
+	void insertCharacter(const uint16_t /* character */) { if (!isUndoOn()) m_currentPageHasContent = true; }
+	void insertTab(const uint8_t /* tabType */, float /* tabPosition */) { if (!isUndoOn()) m_currentPageHasContent = true; }
 	void insertEOL() { if (!isUndoOn()) m_currentPageHasContent = true; }
  	void insertBreak(const uint8_t breakType);
-	void attributeChange(const bool isOn, const uint8_t attribute) {}
-	void lineSpacingChange(const float lineSpacing) {}
-	void justificationChange(const uint8_t justification) {}
+	void attributeChange(const bool /* isOn */, const uint8_t /* attribute */) {}
+	void lineSpacingChange(const float /* lineSpacing */) {}
+	void justificationChange(const uint8_t /* justification */) {}
 	void pageMarginChange(const uint8_t side, const uint16_t margin);
-	void pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation, const bool isPersistent);
+	void pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation);
 	void marginChange(const uint8_t side, const uint16_t margin);
-	void indentFirstLineChange(const int16_t offset) {}
-	void setTabs(const bool isRelative, const std::vector<WPXTabStop> tabStops) {}
-	void columnChange(const WPXTextColumnType columnType, const uint8_t numColumns, const std::vector<float> &columnWidth,
-				  const std::vector<bool> &isFixedWidth) {}
+	void indentFirstLineChange(const int16_t /* offset */) {}
+	void setTabs(const bool /* isRelative */, const std::vector<WPXTabStop> /* tabStops */) {}
+	void columnChange(const WPXTextColumnType /* columnType */, const uint8_t /* numColumns */,
+			const std::vector<float> & /* columnWidth */, const std::vector<bool> & /* isFixedWidth */) {}
 	void endDocument();
 
-	void defineTable(const uint8_t position, const uint16_t leftOffset){}
-	void addTableColumnDefinition(const uint32_t width, const uint32_t leftGutter, const uint32_t rightGutter, const uint32_t attributes,
-				const uint8_t alignment){}
+	void defineTable(const uint8_t /* position */, const uint16_t /* leftOffset */) {}
+	void addTableColumnDefinition(const uint32_t /* width */, const uint32_t /* leftGutter */, const uint32_t /* rightGutter */,
+					const uint32_t /* attributes */, const uint8_t /* alignment */) {}
 	void startTable();
  	void insertRow();
  	void insertCell();
  	void closeCell() {}
 	void closeRow() {}
-	void setTableCellSpan(const uint16_t colSpan, const uint16_t rowSpan) {}
-	void setTableCellFillColor(const RGBSColor * cellFillColor) {}
+	void setTableCellSpan(const uint16_t /* colSpan */, const uint16_t /* rowSpan */) {}
+	void setTableCellFillColor(const RGBSColor * /* cellFillColor */) {}
  	void endTable() {}
 	void undoChange(const uint8_t undoType, const uint16_t undoLevel);
-	void setTextColor(const RGBSColor * fontColor) {}
-	void setTextFont(const WPXString fontName) {}
-	void setFontSize(const uint16_t fontSize) {}
-	void insertPageNumber(const WPXString &pageNumber) {}
-	void insertNoteReference(const WPXString &noteReference) {}
-	void insertNote(const WPXNoteType noteType, WP3SubDocument *subDocument) { if (!isUndoOn()) m_currentPageHasContent = true; }
+	void setTextColor(const RGBSColor * /* fontColor */) {}
+	void setTextFont(const WPXString& /* fontName */) {}
+	void setFontSize(const uint16_t /* fontSize */) {}
+	void insertPageNumber(const WPXString & /* pageNumber */) {}
+	void insertNoteReference(const WPXString & /* noteReference */) {}
+	void insertNote(const WPXNoteType /* noteType */, WP3SubDocument * /* subDocument */) { if (!isUndoOn()) m_currentPageHasContent = true; }
 	void headerFooterGroup(const uint8_t headerFooterType, const uint8_t occurenceBits, WP3SubDocument *subDocument);
 	void suppressPage(const uint16_t suppressCode);
 
@@ -80,6 +80,8 @@ protected:
 	void _handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList, int nextTableIndice = 0);
 
 private:
+	WP3StylesListener(const WP3StylesListener&);
+	WP3StylesListener& operator=(const WP3StylesListener&);
 	WPXPageSpan m_currentPage;
 
 	WPXTableList m_tableList;
