@@ -32,10 +32,10 @@ class WP5UnsupportedFixedLengthGroup : public WP5FixedLengthGroup
 {
  public:
 	WP5UnsupportedFixedLengthGroup(WPXInputStream *input, uint8_t groupID);	
-	void parse(WP5Listener *listener) {}
+	void parse(WP5Listener * /* listener */) {}
 	
  protected:
-	void _readContents(WPXInputStream *input) {}
+	void _readContents(WPXInputStream * /* input */) {}
 };
 
 #endif /* WP5UNSUPPORTEDFIXEDLENGTHGROUP_H */
