@@ -39,11 +39,13 @@
 
 #include <assert.h>
 #include <algorithm>
+#include <time.h>
 
 #define WP6_DEFAULT_FONT_SIZE 12.0f
 #define WP6_DEFAULT_FONT_NAME "Times New Roman"
 
-WP6OutlineDefinition::WP6OutlineDefinition(const WP6OutlineLocation outlineLocation, const uint8_t *numberingMethods, const uint8_t tabBehaviourFlag)
+WP6OutlineDefinition::WP6OutlineDefinition(const WP6OutlineLocation outlineLocation, const uint8_t *numberingMethods,
+						const uint8_t /* tabBehaviourFlag */)
 {
 	_updateNumberingMethods(outlineLocation, numberingMethods);
 }
@@ -61,12 +63,12 @@ WP6OutlineDefinition::WP6OutlineDefinition()
 // outline style is defined in a prefix packet, then you are given more information later
 // in the document)
 // FIXME: make sure this is in the right place
-void WP6OutlineDefinition::update(const uint8_t *numberingMethods, const uint8_t tabBehaviourFlag)
+void WP6OutlineDefinition::update(const uint8_t *numberingMethods, const uint8_t /* tabBehaviourFlag */)
 {
 	_updateNumberingMethods(paragraphGroup, numberingMethods);
 }
 
-void WP6OutlineDefinition::_updateNumberingMethods(const WP6OutlineLocation outlineLocation, const uint8_t *numberingMethods)
+void WP6OutlineDefinition::_updateNumberingMethods(const WP6OutlineLocation /* outlineLocation */, const uint8_t *numberingMethods)
 {
 	for (int i=0; i<WP6_NUM_LIST_LEVELS; i++)
 	{
@@ -100,6 +102,12 @@ void WP6OutlineDefinition::_updateNumberingMethods(const WP6OutlineLocation outl
 }
 
 _WP6ContentParsingState::_WP6ContentParsingState(WPXTableList tableList, int nextTableIndice) :
+	m_bodyText(),
+	m_textBeforeNumber(),
+	m_textBeforeDisplayReference(),
+	m_numberText(),
+	m_textAfterDisplayReference(),
+	m_textAfterNumber(),
 	m_paragraphMarginBottomRelative(1.0f),
 	m_paragraphMarginBottomAbsolute(0.0f),
 
@@ -109,19 +117,27 @@ _WP6ContentParsingState::_WP6ContentParsingState(WPXTableList tableList, int nex
 	m_isListReference(false),
 
 	m_tableList(tableList),
-	m_currentTable(NULL),
+	m_currentTable(0),
 
 	m_nextTableIndice(nextTableIndice),
+	
+	m_listLevelStack(),
+	m_listTypeStack(),
 
 	m_currentOutlineHash(0),
 	m_oldListLevel(0),
+	m_styleStateSequence(),
 	m_putativeListElementHasParagraphNumber(false),
 	m_putativeListElementHasDisplayReferenceNumber(false),
 	
 	m_noteTextPID(0),
+	m_numNestedNotes(0),
 
 	m_leaderCharacter('.'),
-	m_leaderNumSpaces(0)
+	m_leaderNumSpaces(0),
+
+	m_tempTabStops(),
+	m_tempUsePreWP9LeaderMethod()
 
 {
 }
@@ -134,7 +150,8 @@ _WP6ContentParsingState::~_WP6ContentParsingState()
 WP6ContentListener::WP6ContentListener(std::list<WPXPageSpan> &pageList, WPXTableList tableList, WPXHLListenerImpl *listenerImpl) :
 	WP6Listener(),
 	WPXContentListener(pageList, listenerImpl),
-	m_parseState(new WP6ContentParsingState(tableList))
+	m_parseState(new WP6ContentParsingState(tableList)),
+	m_outlineDefineHash()
 {
 }
 
@@ -148,12 +165,80 @@ WP6ContentListener::~WP6ContentListener()
 	delete m_parseState;
 }
 
+void WP6ContentListener::setDate(const uint16_t type, const uint16_t year, 
+				 const uint8_t month, const uint8_t day, 
+				 const uint8_t hour, const uint8_t minute, 
+				 const uint8_t second, const uint8_t dayOfWeek, 
+				 const uint8_t timeZone, const uint8_t unused)
+{
+        #define DATEBUFLEN 100  // length of buffer allocated for strftime()
+        #define WPMONDAYOFFSET  1       // WP week starts Monday, tm_wday on Sunday
+        #define TMMONTHOFFSET   1       // tm_mon is [0,11], i.e. months since January
+        #define TMYEAROFFSET    1900    // tm_year is days since 1900
+        #define DAYSINWEEK      7       // I hate magic numbers buried in code :-)
+        char    dateBuffer[DATEBUFLEN];    // points to buffer allocated for strftime()
+        int     retVal;         // return value from strftime()
+        struct  tm      m_tm;   // passed to strftime();
+        const char    *dateFormat = "%Y-%m-%dT%H:%M:%S";
+			// This date format is ALMOST the "Complete date plus hours, minutes and 
+			// seconds" format described at http://www.w3.org/TR/NOTE-datetime, i.e.
+			// YYYY-MM-DDThh:mm:ssTZD (eg 1997-07-16T19:20:30+01:00), but without TZD.
+			// WordPerfect does not use the timeZone field, so we don't know the offset
+        WPXString dateStr;      // filled in and passed to m_metaData.insert()
+
+        m_tm.tm_sec       = second;
+        m_tm.tm_min       = minute;
+        m_tm.tm_hour      = hour;
+        m_tm.tm_mday      = day;
+        m_tm.tm_mon       = month - TMMONTHOFFSET;
+        m_tm.tm_year      = year - TMYEAROFFSET;
+        m_tm.tm_wday      = (dayOfWeek + WPMONDAYOFFSET) % DAYSINWEEK;
+        m_tm.tm_yday      = 0;
+        m_tm.tm_isdst     = -1;
+
+        retVal = strftime(dateBuffer, DATEBUFLEN, dateFormat, &m_tm);
+        if (retVal <= 0) {
+                // error - date wouldn't fit in buffer
+                dateStr.sprintf("ERROR: %d character buffer too short for date", DATEBUFLEN);
+        }
+        else {
+                dateStr.sprintf("%s", dateBuffer);
+        }
+
+	switch (type)
+	{
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_CREATION_DATE):
+			m_metaData.insert("meta:creation-date", dateStr);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DATE_COMPLETED):
+			// output two forms until we decide which to use
+			m_metaData.insert("libwpd:completed-date", dateStr);
+			m_metaData.insert("dcterms:available", dateStr);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_RECORDED_DATE):
+			m_metaData.insert("libwpd:recorded-date", dateStr);
+			break;
+		// NOTE: Revision Date is not set in WP Document Summary
+		// and sometimes contains non-zero data, so it's confusing.
+		// WordPerfect actually uses the file modification time
+		// to display Revision Date in Properties.
+		//case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_REVISION_DATE):
+		//	m_metaData.insert("libwpd:revision-date", dateStr);
+		//	break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_VERSION_DATE):
+			// output two forms until we decide which to use
+			m_metaData.insert("libwpd:version-date", dateStr);
+			m_metaData.insert("dcterms:issued", dateStr);
+			break;
+	}
+}
+
 void WP6ContentListener::setExtendedInformation(const uint16_t type, const WPXString &data)
 {
 	switch (type)
 	{
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_AUTHOR):
-			m_metaData.insert("dc:creator", data);
+			m_metaData.insert("meta:initial-creator", data);
 			break;
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_SUBJECT):
 			m_metaData.insert("dc:subject", data);
@@ -165,13 +250,13 @@ void WP6ContentListener::setExtendedInformation(const uint16_t type, const WPXSt
 			m_metaData.insert("dc:type", data);
 			break;
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_KEYWORDS):
-			m_metaData.insert("libwpd:keywords", data);
+			m_metaData.insert("meta:keyword", data);
 			break;
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_LANGUAGE):
 			m_metaData.insert("dc:language", data);
 			break;
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_ABSTRACT):
-			m_metaData.insert("libwpd:abstract", data);
+			m_metaData.insert("dc:description", data);
 			break;
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DESCRIPTIVE_NAME):
 			m_metaData.insert("libwpd:descriptive-name", data);
@@ -179,6 +264,119 @@ void WP6ContentListener::setExtendedInformation(const uint16_t type, const WPXSt
 		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DESCRIPTIVE_TYPE):
 			m_metaData.insert("libwpd:descriptive-type", data);
 			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_ACCOUNT):
+			m_metaData.insert("libwpd:account", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_ADDRESS):
+			m_metaData.insert("libwpd:address", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_ATTACHMENTS):
+			m_metaData.insert("libwpd:attachments", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_AUTHORIZATION):
+			m_metaData.insert("libwpd:authorization", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_BILL_TO):
+			m_metaData.insert("libwpd:bill-to", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_BLIND_COPY):
+			m_metaData.insert("libwpd:blind-copy", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_CARBON_COPY):
+			m_metaData.insert("libwpd:carbon-copy", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_CHECKED_BY):
+			m_metaData.insert("libwpd:checked-by", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_CLIENT):
+			m_metaData.insert("libwpd:client", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_COMMENTS):
+			m_metaData.insert("libwpd:comments", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DEPARTMENT):
+			m_metaData.insert("libwpd:department", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DESTINATION):
+			m_metaData.insert("libwpd:destination", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DISPOSITION):
+			m_metaData.insert("libwpd:disposition", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DIVISION):
+			m_metaData.insert("libwpd:division", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DOCUMENT_NUMBER):
+			m_metaData.insert("libwpd:document-number", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_EDITOR):
+			m_metaData.insert("libwpd:editor", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_FORWARD_TO):
+			m_metaData.insert("libwpd:forward-to", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_GROUP):
+			m_metaData.insert("libwpd:group", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_MAIL_STOP):
+			m_metaData.insert("libwpd:mail-stop", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_MATTER):
+			m_metaData.insert("libwpd:matter", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_OFFICE):
+			m_metaData.insert("libwpd:office", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_OWNER):
+			m_metaData.insert("libwpd:owner", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_PROJECT):
+			m_metaData.insert("libwpd:project", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_PURPOSE):
+			m_metaData.insert("libwpd:purpose", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_RECEIVED_FROM):
+			m_metaData.insert("libwpd:received-from", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_RECORDED_BY):
+			m_metaData.insert("libwpd:recorded-by", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_REFERENCE):
+			m_metaData.insert("libwpd:reference", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_REVISION_NOTES):
+			m_metaData.insert("libwpd:revision-notes", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_REVISION_NUMBER):
+			m_metaData.insert("libwpd:revision-number", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_SECTION):
+			m_metaData.insert("libwpd:section", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_SECURITY):
+			m_metaData.insert("libwpd:security", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_SOURCE):
+			m_metaData.insert("dc:source", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_STATUS):
+			m_metaData.insert("libwpd:status", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_TELEPHONE_NUMBER):
+			m_metaData.insert("libwpd:telephone-number", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_TYPIST):
+			m_metaData.insert("dc:creator", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_VERSION_NOTES):
+			m_metaData.insert("libwpd:version-notes", data);
+			break;
+		case (WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_VERSION_NUMBER):
+			m_metaData.insert("libwpd:version-number", data);
+			break;
+		default:
+		        break;
 	}
 }
 
@@ -501,7 +699,7 @@ void WP6ContentListener::fontChange(const uint16_t matchedFontPointSize, const u
 		_closeSpan();
 		if (matchedFontPointSize)
 		{
-			m_ps->m_fontSize = rint((double)((((double)matchedFontPointSize)/100.0f)*2.0f));
+			m_ps->m_fontSize = (float)rint((double)((((double)matchedFontPointSize)/100.0f)*2.0f));
 			// We compute the real space after paragraph in inches using the size of the font and relative spacing.
 			// We have to recompute this every change of fontSize.
 			m_ps->m_paragraphMarginBottom =
@@ -510,8 +708,9 @@ void WP6ContentListener::fontChange(const uint16_t matchedFontPointSize, const u
 		}
 		if (fontPID)
 		{
-			const WP6FontDescriptorPacket *fontDescriptorPacket = NULL;
-			if (fontDescriptorPacket = dynamic_cast<const WP6FontDescriptorPacket *>(WP6Listener::getPrefixDataPacket(fontPID))) {
+			const WP6FontDescriptorPacket *fontDescriptorPacket = 
+				dynamic_cast<const WP6FontDescriptorPacket *>(WP6Listener::getPrefixDataPacket(fontPID));
+			if (fontDescriptorPacket) {
 				*(m_ps->m_fontName) = fontDescriptorPacket->getFontName();
 			}
 		}
@@ -709,8 +908,8 @@ void WP6ContentListener::indentFirstLineChange(int16_t offset)
 	}
 }
 
-void WP6ContentListener::columnChange(const WPXTextColumnType columnType, const uint8_t numColumns, const std::vector<float> &columnWidth,
-		const std::vector<bool> &isFixedWidth)
+void WP6ContentListener::columnChange(const WPXTextColumnType /* columnType */, const uint8_t numColumns,
+					const std::vector<float> &columnWidth, const std::vector<bool> &isFixedWidth)
 {
 	if (!isUndoOn())
 	{
@@ -730,7 +929,7 @@ void WP6ContentListener::columnChange(const WPXTextColumnType columnType, const
 		if (numColumns > 1)
 		{
 			int i;
-			for (i=0; i<columnWidth.size(); i++)
+			for (i=0; i<(int)columnWidth.size(); i++)
 			{
 				if (isFixedWidth[i])
 					remainingSpace -= columnWidth[i];
@@ -800,7 +999,7 @@ void WP6ContentListener::updateOutlineDefinition(const WP6OutlineLocation outlin
 	}
 }
 
-void WP6ContentListener::paragraphNumberOn(const uint16_t outlineHash, const uint8_t level, const uint8_t flag)
+void WP6ContentListener::paragraphNumberOn(const uint16_t outlineHash, const uint8_t level, const uint8_t /* flag */)
 {
 	if (!isUndoOn())
 	{
@@ -822,7 +1021,7 @@ void WP6ContentListener::paragraphNumberOff()
 	}
 }
 
-void WP6ContentListener::displayNumberReferenceGroupOn(const uint8_t subGroup, const uint8_t level)
+void WP6ContentListener::displayNumberReferenceGroupOn(const uint8_t subGroup, const uint8_t /* level */)
 {
 	if (!isUndoOn())
 	{
@@ -961,6 +1160,12 @@ void WP6ContentListener::noteOn(const uint16_t textPID)
 {
 	if (!isUndoOn())
 	{
+		if (m_ps->m_isNote)
+		{
+			m_parseState->m_numNestedNotes++;
+			return;
+		}
+
 		_closeSpan();
 		m_parseState->m_styleStateSequence.setCurrentState(DOCUMENT_NOTE);
 		// save a reference to the text PID, we want to parse
@@ -974,21 +1179,28 @@ void WP6ContentListener::noteOff(const WPXNoteType noteType)
 {
 	if (!isUndoOn())
 	{
+		if (m_parseState->m_numNestedNotes > 0)
+		{
+			m_parseState->m_numNestedNotes--;
+			return;
+		}
+
 		m_parseState->m_styleStateSequence.setCurrentState(NORMAL);
 		WPXNumberingType numberingType = _extractWPXNumberingTypeFromBuf(m_parseState->m_numberText, ARABIC);
 		int number = _extractDisplayReferenceNumberFromBuf(m_parseState->m_numberText, numberingType);
 		m_parseState->m_numberText.clear(); // we do not need the text version of the number anymore
 
 		WPXPropertyList propList;
-		propList.insert("libwpd:number", number);
+		if (number)
+			propList.insert("libwpd:number", number);
 
 		if (noteType == FOOTNOTE)
 			m_listenerImpl->openFootnote(propList);
 		else
 			m_listenerImpl->openEndnote(propList);
 
-		uint16_t textPID = m_parseState->m_noteTextPID;
-		handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : NULL), 
+		uint16_t textPID = (uint16_t)m_parseState->m_noteTextPID;
+		handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), 
 				false, m_parseState->m_tableList, m_parseState->m_nextTableIndice);
 
 		if (noteType == FOOTNOTE)
@@ -996,6 +1208,7 @@ void WP6ContentListener::noteOff(const WPXNoteType noteType)
 		else
 			m_listenerImpl->closeEndnote();
 		m_ps->m_isNote = false;
+		m_parseState->m_numNestedNotes = 0;
 	}
 }
 
@@ -1037,8 +1250,8 @@ void WP6ContentListener::defineTable(const uint8_t position, const uint16_t left
 		m_ps->m_tableDefinition.m_leftOffset = (float)((double)leftOffset / (double)WPX_NUM_WPUS_PER_INCH) - m_ps->m_paragraphMarginLeft;
 
 		// remove all the old column information
-		m_ps->m_tableDefinition.columns.clear();
-		m_ps->m_tableDefinition.columnsProperties.clear();
+		m_ps->m_tableDefinition.m_columns.clear();
+		m_ps->m_tableDefinition.m_columnsProperties.clear();
 
 		// pull a table definition off of our stack
 		m_parseState->m_currentTable = m_parseState->m_tableList[m_parseState->m_nextTableIndice++];
@@ -1047,8 +1260,8 @@ void WP6ContentListener::defineTable(const uint8_t position, const uint16_t left
 	}
 }
 
-void WP6ContentListener::addTableColumnDefinition(const uint32_t width, const uint32_t leftGutter, const uint32_t rightGutter,
-												  const uint32_t attributes, const uint8_t alignment)
+void WP6ContentListener::addTableColumnDefinition(const uint32_t width, const uint32_t /* leftGutter */,
+						const uint32_t /* rightGutter */, const uint32_t attributes, const uint8_t alignment)
 {
 	if (!isUndoOn())
 	{
@@ -1063,9 +1276,9 @@ void WP6ContentListener::addTableColumnDefinition(const uint32_t width, const ui
 		colProp.m_alignment = alignment;
 		
 		// add the new column definition to our table definition
-		m_ps->m_tableDefinition.columns.push_back(colDef);
+		m_ps->m_tableDefinition.m_columns.push_back(colDef);
 		
-		m_ps->m_tableDefinition.columnsProperties.push_back(colProp);
+		m_ps->m_tableDefinition.m_columnsProperties.push_back(colProp);
 
 		// initialize the variable that tells us how many columns to skip
 		m_ps->m_numRowsToSkip.push_back(0);
@@ -1096,7 +1309,7 @@ void WP6ContentListener::startTable()
 
 void WP6ContentListener::insertRow(const uint16_t rowHeight, const bool isMinimumHeight, const bool isHeaderRow)
 {
-	if (!isUndoOn())
+	if (!isUndoOn() && m_ps->m_isTableOpened)
 	{
 		_flushText();
 		float rowHeightInch = (float)((double) rowHeight / (double)WPX_NUM_WPUS_PER_INCH);
@@ -1104,12 +1317,12 @@ void WP6ContentListener::insertRow(const uint16_t rowHeight, const bool isMinimu
 	}
 }
 
-void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits, 
+void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t /* borderBits */, 
 					const RGBSColor * cellFgColor, const RGBSColor * cellBgColor, 
 					const RGBSColor * cellBorderColor, const WPXVerticalAlignment cellVerticalAlignment, 
 					const bool useCellAttributes, const uint32_t cellAttributes)
 {
-	if (!isUndoOn())
+	if (!isUndoOn() && m_ps->m_isTableOpened)
 	{
 		if (m_ps->m_currentTableRow < 0) // cell without a row, invalid
 		{
@@ -1123,13 +1336,13 @@ void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan
 			throw ParseException(); // no table opened, invalid
 		}
 			
-		if (m_parseState->m_currentTable->getRows().size() <= m_ps->m_currentTableRow)
+		if ((int)m_parseState->m_currentTable->getRows().size() <= (int)m_ps->m_currentTableRow)
 		{
 			WPD_DEBUG_MSG(("Requesting a row larger than the number of rows the table holds\n"));
 			throw ParseException(); // requesting a row larger than the number of rows the table holds
 		}
 			
-		if (m_parseState->m_currentTable->getRows()[m_ps->m_currentTableRow].size() <= m_ps->m_currentTableCellNumberInRow)
+		if ((int)m_parseState->m_currentTable->getRows()[m_ps->m_currentTableRow].size() <= (int)m_ps->m_currentTableCellNumberInRow)
 		{
 			WPD_DEBUG_MSG(("Requesting a cell smaller than the number of cells in the row\n"));
 			throw ParseException(); // requesting a cell smaller than the number of cells in the row
@@ -1144,8 +1357,8 @@ void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan
 		if (useCellAttributes)
 			m_ps->m_cellAttributeBits = cellAttributes;
 		else
-			m_ps->m_cellAttributeBits = m_ps->m_tableDefinition.columnsProperties[m_ps->m_currentTableCol-1].m_attributes;
-		justificationChange(m_ps->m_tableDefinition.columnsProperties[m_ps->m_currentTableCol-1].m_alignment);
+			m_ps->m_cellAttributeBits = m_ps->m_tableDefinition.m_columnsProperties[m_ps->m_currentTableCol-1].m_attributes;
+		justificationChange(m_ps->m_tableDefinition.m_columnsProperties[m_ps->m_currentTableCol-1].m_alignment);
 	}
 }
 
@@ -1167,6 +1380,7 @@ void WP6ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, c
 	WP6ContentParsingState *oldParseState = m_parseState;
 	
 	m_parseState = new WP6ContentParsingState(tableList, nextTableIndice);
+	m_parseState->m_numNestedNotes = oldParseState->m_numNestedNotes;
 
 	if (isHeaderFooter)
 	{
@@ -1197,6 +1411,7 @@ void WP6ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, c
 	// if we are in a foot/endNote, the nextTableIndice sequence has to be maintained
 	if (!isHeaderFooter)
 		oldParseState->m_nextTableIndice = m_parseState->m_nextTableIndice;
+	oldParseState->m_numNestedNotes = m_parseState->m_numNestedNotes;
 
 	// restore our old parsing state
 	delete m_parseState;
@@ -1259,7 +1474,7 @@ void WP6ContentListener::_flushText()
 	
 	if (m_parseState->m_numListExtraTabs > 0)
 	{
-		for (m_parseState->m_numListExtraTabs; m_parseState->m_numListExtraTabs > 0; m_parseState->m_numListExtraTabs--)
+		for (; m_parseState->m_numListExtraTabs > 0; m_parseState->m_numListExtraTabs--)
 			m_listenerImpl->insertTab();
 		m_parseState->m_numListExtraTabs = 0;
 	}
@@ -1390,7 +1605,7 @@ void WP6ContentListener::_changeList()
 	_handleListChange(m_parseState->m_currentOutlineHash);
 }
 
-void WP6ContentListener::undoChange(const uint8_t undoType, const uint16_t undoLevel)
+void WP6ContentListener::undoChange(const uint8_t undoType, const uint16_t /* undoLevel */)
 {
 	if (undoType == WP6_UNDO_GROUP_INVALID_TEXT_START)
 		setUndoOn(true);
