@@ -30,6 +30,7 @@
 #include "WPXFileStructure.h"
 #include "libwpd_internal.h"
 #include "WP6SubDocument.h"
+#include "WP6PrefixDataPacket.h"
 
 // WP6StylesListener: creates intermediate table and page span representations, given a
 // sequence of messages passed to it by the parser.
@@ -37,17 +38,17 @@
 WP6StylesListener::WP6StylesListener(std::list<WPXPageSpan> &pageList, WPXTableList tableList) : 
 	WP6Listener(),
 	WPXStylesListener(pageList),
-	m_currentPage(WPXPageSpan()),
-	m_currentTable(NULL),
-	m_pageListHardPageMark(m_pageList.end()),
+	m_currentPage(),
 	m_tableList(tableList), 
+	m_currentTable(0),
 	m_tempMarginLeft(1.0f),
 	m_tempMarginRight(1.0f),
 	m_currentPageHasContent(false),
 	m_isTableDefined(false),
-	m_isSubDocument(false)
+	m_isSubDocument(false),
+	m_subDocuments(),
+	m_pageListHardPageMark(m_pageList.end())
 {
-	m_pageListHardPageMark = m_pageList.end();
 }
 
 void WP6StylesListener::endDocument()
@@ -108,7 +109,7 @@ void WP6StylesListener::pageMarginChange(const uint8_t side, const uint16_t marg
 	}
 }
 
-void WP6StylesListener::pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation, const bool isPersistent)
+void WP6StylesListener::pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation)
 {
 	if (!isUndoOn())
 	{
@@ -189,8 +190,8 @@ void WP6StylesListener::headerFooterGroup(const uint8_t headerFooterType, const
 
 			WPXTableList tableList; 
 			m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence,
-						((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : NULL), tableList);
-			_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : NULL), true, tableList);
+						((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), tableList);
+			_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), true, tableList);
 		}
 		m_currentPageHasContent = tempCurrentPageHasContent;
 	}
@@ -212,7 +213,7 @@ void WP6StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
 	}
 }
 
-void WP6StylesListener::defineTable(const uint8_t position, const uint16_t leftOffset)
+void WP6StylesListener::defineTable(const uint8_t /* position */, const uint16_t /* leftOffset */)
 {
 	if (!isUndoOn()) 
 	{			
@@ -240,12 +241,13 @@ void WP6StylesListener::endTable()
 	if (!isUndoOn())
 	{
 		m_isTableDefined = false;
+		m_currentTable = 0;
 	}
 }
 
-void WP6StylesListener::insertRow(const uint16_t rowHeight, const bool isMinimumHeight, const bool isHeaderRow)
+void WP6StylesListener::insertRow(const uint16_t /* rowHeight */, const bool /* isMinimumHeight */, const bool /* isHeaderRow */)
 {
-	if (!isUndoOn()) 
+	if (!isUndoOn() && m_currentTable) 
 	{
 		m_currentPageHasContent = true;
 		m_currentTable->insertRow();
@@ -253,11 +255,11 @@ void WP6StylesListener::insertRow(const uint16_t rowHeight, const bool isMinimum
 }
 
 void WP6StylesListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits, 
-				const RGBSColor * cellFgColor, const RGBSColor * cellBgColor,
-				const RGBSColor * cellBorderColor, const WPXVerticalAlignment cellVerticalAlignment, 
-				const bool useCellAttributes, const uint32_t cellAttributes)
+				const RGBSColor * /* cellFgColor */, const RGBSColor * /* cellBgColor */,
+				const RGBSColor * /* cellBorderColor */, const WPXVerticalAlignment /* cellVerticalAlignment */, 
+				const bool /* useCellAttributes */, const uint32_t /* cellAttributes */)
 {
-	if (!isUndoOn())
+	if (!isUndoOn() && m_currentTable)
 	{
 		m_currentPageHasContent = true;
 		m_currentTable->insertCell(colSpan, rowSpan, borderBits);
@@ -269,11 +271,12 @@ void WP6StylesListener::noteOn(const uint16_t textPID)
 	if (!isUndoOn()) 
 	{
 		m_currentPageHasContent = true; 		
-		_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : NULL), false, m_tableList);
+		_handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), false, m_tableList);
 	}
 }
 
-void WP6StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList, int nextTableIndice)
+void WP6StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList,
+						int /* nextTableIndice */)
 {
 	// We don't want to actual insert anything in the case of a sub-document, but we
 	// do want to capture whatever table-related information is within it..
@@ -311,7 +314,7 @@ void WP6StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, co
 	}
 }
 
-void WP6StylesListener::undoChange(const uint8_t undoType, const uint16_t undoLevel)
+void WP6StylesListener::undoChange(const uint8_t undoType, const uint16_t /* undoLevel */)
 {
 	if (undoType == WP6_UNDO_GROUP_INVALID_TEXT_START)
 		setUndoOn(true);
