@@ -32,7 +32,7 @@ _WPXContentParsingState::_WPXContentParsingState() :
 	m_fontSize(12.0f/*WP6_DEFAULT_FONT_SIZE*/), // FIXME ME!!!!!!!!!!!!!!!!!!! HELP WP6_DEFAULT_FONT_SIZE
 	m_fontName(new WPXString(/*WP6_DEFAULT_FONT_NAME*/"Times New Roman")), // EN PAS DEFAULT FONT AAN VOOR WP5/6/etc
 	m_fontColor(new RGBSColor(0x00,0x00,0x00,0x64)), //Set default to black. Maybe once it will change, but for the while...
-	m_highlightColor(NULL),
+	m_highlightColor(0),
 
 	m_isParagraphColumnBreak(false),
 	m_isParagraphPageBreak(false),
@@ -49,22 +49,27 @@ _WPXContentParsingState::_WPXContentParsingState() :
 	m_isSpanOpened(false),
 	m_isParagraphOpened(false),
 	m_isListElementOpened(false),
-
+	
+	m_numRowsToSkip(),
+	m_tableDefinition(),
 	m_currentTableCol(0),
 	m_currentTableRow(0),
 	m_currentTableCellNumberInRow(0),
 	m_isTableOpened(false),
 	m_isTableRowOpened(false),
+	m_isTableColumnOpened(false),
 	m_isTableCellOpened(false),
 	m_wasHeaderRow(false),
 	m_isCellWithoutParagraph(false),
 	m_cellAttributeBits(0x00000000),
 	m_paragraphJustificationBeforeTable(WPX_PARAGRAPH_JUSTIFICATION_LEFT),
-
+	
+	m_nextPageSpanIter(),
 	m_numPagesRemainingInSpan(0),
 
 	m_sectionAttributesChanged(false),
 	m_numColumns(1),
+	m_textColumns(),
 	m_isTextColumnWithoutParagraph(false),
 
 	m_pageFormLength(11.0f),
@@ -96,7 +101,11 @@ _WPXContentParsingState::_WPXContentParsingState() :
 	m_currentListLevel(0),
 
 	m_alignmentCharacter('.'),
+	m_tabStops(),
 	m_isTabPositionRelative(false),
+	
+	m_subDocuments(),
+	
 	m_inSubDocument(false),
 	m_isNote(false)
 {
@@ -112,7 +121,8 @@ _WPXContentParsingState::~_WPXContentParsingState()
 WPXContentListener::WPXContentListener(std::list<WPXPageSpan> &pageList, WPXHLListenerImpl *listenerImpl) :
 	WPXListener(pageList),
 	m_ps(new WPXContentParsingState),
-	m_listenerImpl(listenerImpl)
+	m_listenerImpl(listenerImpl),
+	m_metaData()
 {
 	m_ps->m_nextPageSpanIter = pageList.begin();
 }
@@ -290,7 +300,7 @@ void WPXContentListener::_openPageSpan()
 	{
 		if (!currentPage.getHeaderFooterSuppression((*iter).getInternalType()))
 		{
-			WPXPropertyList propList;
+			propList.clear();
 			switch ((*iter).getOccurence())
 			{
 			case ODD:
@@ -302,6 +312,9 @@ void WPXContentListener::_openPageSpan()
 			case ALL:
 				propList.insert("libwpd:occurence", "all");
 				break;
+			case NEVER:
+			default:
+				break;
 			}
 
 			if ((*iter).getType() == HEADER)
@@ -469,7 +482,7 @@ void WPXContentListener::_appendParagraphProperties(WPXPropertyList &propList, c
 
 void WPXContentListener::_getTabStops(WPXPropertyListVector &tabStops)
 {
-	for (int i=0; i<m_ps->m_tabStops.size(); i++)
+	for (int i=0; i<(int)m_ps->m_tabStops.size(); i++)
 	{
 		WPXPropertyList tmpTabStop;
 
@@ -504,6 +517,8 @@ void WPXContentListener::_getTabStops(WPXPropertyListVector &tabStops)
 			position -= m_ps->m_leftMarginByTabs;
 		else
 			position -= m_ps->m_paragraphMarginLeft + m_ps->m_sectionMarginLeft + m_ps->m_pageMarginLeft;
+		if (position < 0.00005f && position > -0.00005f)
+			position = 0.0f;
 		tmpTabStop.insert("style:position", position);
 		
 
@@ -615,13 +630,15 @@ void WPXContentListener::_openSpan()
 
 	WPXPropertyList propList;
  	if (attributeBits & WPX_SUPERSCRIPT_BIT) {
-		WPXString sSuperScript;
-		sSuperScript.sprintf("super %f%%", WPX_DEFAULT_SUPER_SUB_SCRIPT);
+		WPXString sSuperScript("super ");
+		sSuperScript.append(doubleToString(WPX_DEFAULT_SUPER_SUB_SCRIPT));
+		sSuperScript.append("%");
 		propList.insert("style:text-position", sSuperScript);
 	}
  	else if (attributeBits & WPX_SUBSCRIPT_BIT) {
-		WPXString sSubScript;
-		sSubScript.sprintf("sub %f%%", WPX_DEFAULT_SUPER_SUB_SCRIPT);
+		WPXString sSubScript("sub ");
+		sSubScript.append(doubleToString(WPX_DEFAULT_SUPER_SUB_SCRIPT));
+		sSubScript.append("%");
 		propList.insert("style:text-position", sSubScript);
 	}
 	if (attributeBits & WPX_ITALICS_BIT)
@@ -717,7 +734,7 @@ void WPXContentListener::_openTable()
  	float tableWidth = 0.0f;
 	WPXPropertyListVector columns;
  	typedef std::vector<WPXColumnDefinition>::const_iterator CDVIter;
- 	for (CDVIter iter = m_ps->m_tableDefinition.columns.begin(); iter != m_ps->m_tableDefinition.columns.end(); iter++)
+ 	for (CDVIter iter = m_ps->m_tableDefinition.m_columns.begin(); iter != m_ps->m_tableDefinition.m_columns.end(); iter++)
  	{
 		WPXPropertyList column;
 		// The "style:rel-width" is expressed in twips (1440 twips per inch) and includes the left and right Gutter
@@ -800,14 +817,14 @@ void WPXContentListener::_closeTableRow()
 {
 	if (m_ps->m_isTableRowOpened)
 	{
-		while (m_ps->m_currentTableCol < m_ps->m_numRowsToSkip.size())
+		while ((long)m_ps->m_currentTableCol < (long)m_ps->m_numRowsToSkip.size())
 		{
 			if (!m_ps->m_numRowsToSkip[m_ps->m_currentTableCol]) // This case should not happen, but does :-(
 			{
 				// m_ps->m_currentTableCol++;
 				// Fill the table row untill the end with empty cells
 				RGBSColor tmpCellBorderColor(0x00, 0x00, 0x00, 0x64);
-				_openTableCell(1, 1, 0xFF, NULL, NULL, &tmpCellBorderColor, TOP);
+				_openTableCell(1, 1, 0xFF, 0, 0, &tmpCellBorderColor, TOP);
 				_closeTableCell();
 			}
 			else
@@ -844,11 +861,14 @@ static void addBorderProps(const char *border, bool borderOn, const WPXString &b
 	borderStyle.sprintf("fo:border-%s", border);
 	WPXString props;
 	if (borderOn)
-		props.sprintf("%finch solid %s", WPX_DEFAULT_TABLE_BORDER_WIDTH, borderColor.cstr());
+	{
+	  props.append(doubleToString(WPX_DEFAULT_TABLE_BORDER_WIDTH));
+	  props.append("inch solid ");
+	  props.append(borderColor);
+	}
 	else
 		props.sprintf("0.0inch");
 	propList.insert(borderStyle.cstr(), props);
-	WPXString borderOff;
 }
 
 void WPXContentListener::_openTableCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits,  
@@ -859,7 +879,7 @@ void WPXContentListener::_openTableCell(const uint8_t colSpan, const uint8_t row
 	if (m_ps->m_isTableCellOpened)
 		_closeTableCell();
 
-	while (m_ps->m_currentTableCol < m_ps->m_numRowsToSkip.size() && m_ps->m_numRowsToSkip[m_ps->m_currentTableCol])
+	while ((long)m_ps->m_currentTableCol < (long)m_ps->m_numRowsToSkip.size() && m_ps->m_numRowsToSkip[m_ps->m_currentTableCol])
 	{
 		m_ps->m_numRowsToSkip[m_ps->m_currentTableCol]--;
 		m_ps->m_currentTableCol++;
@@ -899,7 +919,7 @@ void WPXContentListener::_openTableCell(const uint8_t colSpan, const uint8_t row
 	m_ps->m_isTableCellOpened = true;
 	m_ps->m_isCellWithoutParagraph = true;
 
-	while ((m_ps->m_currentTableCol < m_ps->m_numRowsToSkip.size()) && (tmpColSpan > 0))
+	while (((long)m_ps->m_currentTableCol < (long)m_ps->m_numRowsToSkip.size()) && (tmpColSpan > 0))
 	{
 		if (m_ps->m_numRowsToSkip[m_ps->m_currentTableCol]) // This case should not happen, but it happens in real-life documents :-(
 		{
@@ -1090,7 +1110,7 @@ WPXString WPXContentListener::_mergeColorsToString(const RGBSColor *fgColor, con
 	WPXString tmpColor;
 	RGBSColor tmpFgColor, tmpBgColor;
 
-	if (fgColor != NULL) {
+	if (fgColor) {
 		tmpFgColor.m_r = fgColor->m_r;
 		tmpFgColor.m_g = fgColor->m_g;
 		tmpFgColor.m_b = fgColor->m_b;
@@ -1100,7 +1120,7 @@ WPXString WPXContentListener::_mergeColorsToString(const RGBSColor *fgColor, con
 		tmpFgColor.m_r = tmpFgColor.m_g = tmpFgColor.m_b = 0xFF;
 		tmpFgColor.m_s = 0x64; // 100%
 	}
-	if (bgColor != NULL) {
+	if (bgColor) {
 		tmpBgColor.m_r = bgColor->m_r;
 		tmpBgColor.m_g = bgColor->m_g;
 		tmpBgColor.m_b = bgColor->m_b;
@@ -1129,7 +1149,7 @@ float WPXContentListener::_movePositionToFirstColumn(float position)
 		return position;
 	float tempSpaceRemaining = position - m_ps->m_pageMarginLeft - m_ps->m_sectionMarginLeft;
 	position -= m_ps->m_textColumns[0].m_leftGutter;
-	for (int i = 0; i < (m_ps->m_textColumns.size() - 1); i++)
+	for (int i = 0; i < (int)(m_ps->m_textColumns.size() - 1); i++)
 	{
 		if ((tempSpaceRemaining -= m_ps->m_textColumns[i].m_width - m_ps->m_textColumns[i].m_rightGutter) > 0)
 		{
