@@ -1,6 +1,6 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -41,31 +41,30 @@ typedef struct _WPXTableCell WPXTableCell;
 
 struct _WPXTableCell
 {
-	_WPXTableCell(uint8_t colSpan, uint8_t rowSpan, bool boundFromLeft, bool boundFromAbove, uint8_t borderBits);
+	_WPXTableCell(uint8_t colSpan, uint8_t rowSpan, uint8_t borderBits);
 	uint8_t m_colSpan;
 	uint8_t m_rowSpan;
-	bool m_boundFromLeft, m_boundFromAbove;
 	uint8_t m_borderBits;
 };
 
 class WPXTable
 {
 public:
-	WPXTable() {}
+	WPXTable() : m_tableRows(std::vector< std::vector<WPXTableCell *> >()) {}
 	~WPXTable();
 	void insertRow();
-	void insertCell(uint8_t colSpan, uint8_t rowSpan, bool boundFromLeft, bool boundFromAbove, uint8_t borderBits);
-	const WPXTableCell * getCell(int i, int j) { return (*m_tableRows[i])[j]; }
+	void insertCell(uint8_t colSpan, uint8_t rowSpan, uint8_t borderBits);
+	const WPXTableCell*  getCell(int i, int j) { return (m_tableRows[i])[j]; }
 	void makeBordersConsistent();
-	void _makeCellBordersConsistent(WPXTableCell *cell, std::vector<WPXTableCell *> *adjacentCells, 
+	void _makeCellBordersConsistent(WPXTableCell *cell, std::vector<WPXTableCell *> &adjacentCells, 
 				      int adjacencyBitCell, int adjacencyBitBoundCells);
-	std::vector<WPXTableCell *> * _getCellsBottomAdjacent(int i, int j);
-	std::vector<WPXTableCell *> * _getCellsRightAdjacent(int i, int j);
+	std::vector<WPXTableCell *>  _getCellsBottomAdjacent(int i, int j);
+	std::vector<WPXTableCell *>  _getCellsRightAdjacent(int i, int j);
 
-	const std::vector< std::vector<WPXTableCell *> * > * getTableRows() const { return &m_tableRows; } // ugly, but whatever
+	const std::vector< std::vector<WPXTableCell *> >& getRows() const { return m_tableRows; }
 
 private:
-	std::vector< std::vector<WPXTableCell *> * > m_tableRows;
+	std::vector< std::vector<WPXTableCell *> > m_tableRows;
 };
 
 class WPXTableList
