@@ -25,6 +25,8 @@
 #include "libwpd_internal.h"
 #include "WPXStream.h"
 #include <ctype.h>
+#include <locale.h>
+#include <string>
 
 uint8_t readU8(WPXInputStream *input)
 {
@@ -969,27 +971,11 @@ _RGBSColor::_RGBSColor()
 }
 
 _RGBSColor::_RGBSColor(uint16_t red, uint16_t green, uint16_t blue)
+	:	m_r((red >> 8) & 0xFF),
+		m_g((green >> 8) & 0xFF),
+		m_b((blue >> 8) & 0xFF),
+		m_s(100)
 {
-	int minRGB = red;
-	if (minRGB > green)
-		minRGB = green;
-	if (minRGB > blue)
-		minRGB = blue;
-		
-	if (minRGB >= 65535)
-	{
-		m_r = 255;
-		m_g = 255;
-		m_b = 255;
-		m_s = 100;
-	}
-	else
-	{
-		m_r = (uint8_t)rint(255*((double)(red - minRGB))/((double)(65535 - minRGB)));
-		m_g = (uint8_t)rint(255*((double)(green - minRGB))/((double)(65535 - minRGB)));
-		m_b = (uint8_t)rint(255*((double)(blue - minRGB))/((double)(65535 - minRGB)));
-		m_s = (uint8_t)rint(100*((double)(65535 - minRGB))/(double)65535);
-	}		
 }
 
 _WPXTabStop::_WPXTabStop(float position, WPXTabAlignment alignment, uint16_t leaderCharacter, uint8_t leaderNumSpaces)
@@ -1072,7 +1058,7 @@ int _extractDisplayReferenceNumberFromBuf(const WPXString &buf, const WPXNumberi
 			throw ParseException();
 		char c = buf.cstr()[0];
 		if (listType==LOWERCASE)
-			c = toupper(c);
+			c = (char)toupper(c);
 		return (c - 64);
 	}
 	else if (listType == ARABIC)
@@ -1169,3 +1155,20 @@ const uint16_t macintoshCharacterMap[] =
   0xf8ff, 0x00d2, 0x00da, 0x00db, 0x00d9, 0x0131, 0x02c6, 0x02dc,
   0x00af, 0x02d8, 0x02d9, 0x02da, 0x00b8, 0x02dd, 0x02db, 0x02c7
 };
+
+WPXString doubleToString(const double value)
+{
+  WPXString tempString;
+  tempString.sprintf("%.4f", value);
+  std::string decimalPoint(localeconv()->decimal_point);
+  if ((decimalPoint.size() == 0) || (decimalPoint == "."))
+    return tempString;
+  std::string stringValue(tempString.cstr());
+  if (!stringValue.empty())
+  {
+    std::string::size_type pos;
+    while ((pos = stringValue.find(decimalPoint)) != std::string::npos)
+          stringValue.replace(pos,decimalPoint.size(),".");
+  }
+  return WPXString(stringValue.c_str());
+}
